import sys
import json
import click
from fastapi import FastAPI
from uvicorn.importer import import_from_string
from generator.lib.exceptions import NotFastAPIException

@click.command()
@click.argument("app")
@click.option(
    "--app-dir",
    "app_dir",
    default=".",
    show_default=True,
    help="Look for APP in the specified directory, by adding this to the PYTHONPATH."
    " Defaults to the current working directory."
)
@click.option(
    "--output-dir",
    "output_dir",
    default=".",
    show_default=True,
    help="The folder where the swagger is stored."
)
def main(app, app_dir, output_dir):
    sys.path.insert(0, app_dir)

    fastapi: FastAPI = import_from_string(app)

    if not isinstance(fastapi, FastAPI):
        raise NotFastAPIException('The given object is not a FastAPI application')

    with open('{}/openapi.json'.format(output_dir), 'w+') as openapi:
        openapi.write(json.dumps(fastapi.openapi(), indent=2))

if __name__ == "__main__":
    main()



# pylint: disable=line-too-long
"""
    :author: Pasquale Carmone Carbone

    Setup module
"""
import setuptools

with open("README.md", "r") as fh:
    LONG_DESCRIPTION = fh.read()

with open('requirements.txt', 'r') as fin:
    REQS = fin.read().splitlines()

setuptools.setup(
    setup_requires=['setuptools-git-version'],
    version_format='{tag}',
    name="fastapi-openapi-generator",
    author="Pasquale Carmine Carbone",
    author_email="pasqualecarmine.carbone@gmail.com",
    description="A Command Line Interface to save openapi file from a FastAPI application",
    long_description=LONG_DESCRIPTION,
    url="https://github.com/KiraPC/fastapi-openapi-generator",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(exclude=['venv', 'fastapi-openapi-generator.egg-info', 'build']),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'fastapi-openapi-gen = generator.main:main'
        ]
    },
    python_requires='>=3.0',
    install_requires=REQS
)
